---
title: EcoLogits
hide:
  - navigation
---

#

<figure class="hero-logo" markdown="span">
  ![EcoLogits](assets/logo_light.png#only-light){ width="500" }
  ![EcoLogits](assets/logo_dark.png#only-dark){ width="500" }
  <figcaption>
    <p class="hero-logo__tagline">Estimate and track the environmental footprint of GenAI models at inference.</p>
    <p class="hero-logo__team">Made with 💚 by <a href="https://codecarbon.io/">CodeCarbon</a> non-profit.</p>
  </figcaption>
</figure>


## Project

**EcoLogits** is a suite of **open source tools** for estimating the **environmental footprint of generative AI models at inference**. Based on **life-cycle assessment principles**, the project raises awareness about the direct environmental impacts of AI while empowering developers and organizations to build **more sustainable AI-powered applications**.

- **Open & transparent** – Code, methodology, and data are openly accessible.
- **Ease of use** – Emphasizes on seamless integration and user experience.
- **Community-driven** – Continuously built and improved collaboratively.


## Tools

<div class="project-cards">
    <div class="project-card calculator">
        <div class="project-card-header">
            <svg xmlns="http://www.w3.org/2000/svg" width="25" height="25" viewBox="0 0 640 640"><!--!Font Awesome Free v7.0.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2025 Fonticons, Inc.--><path d="M192 64C156.7 64 128 92.7 128 128L128 512C128 547.3 156.7 576 192 576L448 576C483.3 576 512 547.3 512 512L512 128C512 92.7 483.3 64 448 64L192 64zM224 128L416 128C433.7 128 448 142.3 448 160L448 192C448 209.7 433.7 224 416 224L224 224C206.3 224 192 209.7 192 192L192 160C192 142.3 206.3 128 224 128zM240 296C240 309.3 229.3 320 216 320C202.7 320 192 309.3 192 296C192 282.7 202.7 272 216 272C229.3 272 240 282.7 240 296zM320 320C306.7 320 296 309.3 296 296C296 282.7 306.7 272 320 272C333.3 272 344 282.7 344 296C344 309.3 333.3 320 320 320zM448 296C448 309.3 437.3 320 424 320C410.7 320 400 309.3 400 296C400 282.7 410.7 272 424 272C437.3 272 448 282.7 448 296zM216 416C202.7 416 192 405.3 192 392C192 378.7 202.7 368 216 368C229.3 368 240 378.7 240 392C240 405.3 229.3 416 216 416zM344 392C344 405.3 333.3 416 320 416C306.7 416 296 405.3 296 392C296 378.7 306.7 368 320 368C333.3 368 344 378.7 344 392zM424 416C410.7 416 400 405.3 400 392C400 378.7 410.7 368 424 368C437.3 368 448 378.7 448 392C448 405.3 437.3 416 424 416zM192 488C192 474.7 202.7 464 216 464L328 464C341.3 464 352 474.7 352 488C352 501.3 341.3 512 328 512L216 512C202.7 512 192 501.3 192 488zM424 464C437.3 464 448 474.7 448 488C448 501.3 437.3 512 424 512C410.7 512 400 501.3 400 488C400 474.7 410.7 464 424 464z"/></svg>
            <h3>EcoLogits Calculator</h3>
        </div>
        <div class="card-content">
            <a href="https://huggingface.co/spaces/genai-impact/ecologits-calculator" target="_blank">
                <img src="assets/calculator_screenshot.png" alt="Calculator Icon">
            </a>
            <p>A <b>user-friendly web tool</b> for estimating the environmental footprint of AI models with just a few clicks.</p>
            <p><a href="https://huggingface.co/spaces/genai-impact/ecologits-calculator" target="_blank">Visit EcoLogits Calculator <span class="twemoji"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16"><path d="M3.75 2h3.5a.75.75 0 0 1 0 1.5h-3.5a.25.25 0 0 0-.25.25v8.5c0 .138.112.25.25.25h8.5a.25.25 0 0 0 .25-.25v-3.5a.75.75 0 0 1 1.5 0v3.5A1.75 1.75 0 0 1 12.25 14h-8.5A1.75 1.75 0 0 1 2 12.25v-8.5C2 2.784 2.784 2 3.75 2m6.854-1h4.146a.25.25 0 0 1 .25.25v4.146a.25.25 0 0 1-.427.177L13.03 4.03 9.28 7.78a.75.75 0 0 1-1.042-.018.75.75 0 0 1-.018-1.042l3.75-3.75-1.543-1.543A.25.25 0 0 1 10.604 1"></path></svg></span></a></p>
        </div>
    </div>
    <div class="project-card">
        <div class="project-card-header">
            <svg xmlns="http://www.w3.org/2000/svg" width="25" height="25" viewBox="0 0 640 640"><!--!Font Awesome Free v7.0.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2025 Fonticons, Inc.--><path d="M535.8 264.5C528.1 233.6 513.5 210.3 482.4 210.3L442.3 210.3L442.3 257.7C442.3 294.5 411.1 325.5 375.5 325.5L268.7 325.5C239.5 325.5 215.3 350.5 215.3 379.8L215.3 481.6C215.3 510.6 240.5 527.6 268.7 535.9C302.5 545.8 335 547.6 375.5 535.9C402.4 528.1 428.9 512.4 428.9 481.6L428.9 440.9L322.2 440.9L322.2 427.3L482.4 427.3C513.5 427.3 525 405.6 535.8 373.1C547 339.6 546.5 307.4 535.8 264.5zM382.2 508.7C374.6 509.2 367.3 505.5 363.3 499C359.4 492.4 359.4 484.3 363.3 477.7C367.3 471.2 374.6 467.5 382.2 468C389.8 467.5 397.1 471.2 401.1 477.7C405 484.3 405 492.4 401.1 499C397.1 505.5 389.8 509.2 382.2 508.7zM263.8 312.1L370.6 312.1C400.3 312.1 424 287.6 424 257.8L424 155.9C424 126.9 399.6 105.2 370.6 100.3C334.8 94.4 295.9 94.7 263.8 100.4C218.6 108.4 210.4 125.1 210.4 156L210.4 196.7L317.3 196.7L317.3 210.3L170.3 210.3C139.2 210.3 112 229 103.5 264.5C93.7 305.2 93.3 330.6 103.5 373.1C111.1 404.7 129.2 427.3 160.3 427.3L197 427.3L197 378.5C197 343.2 227.5 312.1 263.8 312.1zM257.2 128.7C268.5 128.7 277.6 137.8 277.6 149.1C277.6 160.4 268.5 169.5 257.2 169.5C245.9 169.5 236.8 160.4 236.8 149.1C236.8 137.8 245.9 128.7 257.2 128.7z"/></svg>
            <h3>EcoLogits</h3>
        </div>
        <div class="card-content">
            <p>A <b>Python library</b> to track environmental impacts of AI requests made through official client SDKs.<br><a href="../get_started">Learn more <span class="twemoji"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16"><path d="M3.75 2h3.5a.75.75 0 0 1 0 1.5h-3.5a.25.25 0 0 0-.25.25v8.5c0 .138.112.25.25.25h8.5a.25.25 0 0 0 .25-.25v-3.5a.75.75 0 0 1 1.5 0v3.5A1.75 1.75 0 0 1 12.25 14h-8.5A1.75 1.75 0 0 1 2 12.25v-8.5C2 2.784 2.784 2 3.75 2m6.854-1h4.146a.25.25 0 0 1 .25.25v4.146a.25.25 0 0 1-.427.177L13.03 4.03 9.28 7.78a.75.75 0 0 1-1.042-.018.75.75 0 0 1-.018-1.042l3.75-3.75-1.543-1.543A.25.25 0 0 1 10.604 1"></path></svg></span></a></p>
            <div class="code-snippet-container">
                <div class="code-snippet">pip install ecologits</div>
                <button class="copy-button" onclick="copyToClipboard(this)">
                    <svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
                        <rect x="9" y="9" width="13" height="13" rx="2" ry="2"></rect>
                        <path d="M5 15H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h9a2 2 0 0 1 2 2v1"></path>
                    </svg>
                </button>
            </div>
        </div>
    </div>
    <div class="project-card">
        <div class="project-card-header">
            <svg xmlns="http://www.w3.org/2000/svg" width="25" height="25" viewBox="0 0 640 640"><!--!Font Awesome Free v7.0.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2025 Fonticons, Inc.--><path d="M392.8 65.2C375.8 60.3 358.1 70.2 353.2 87.2L225.2 535.2C220.3 552.2 230.2 569.9 247.2 574.8C264.2 579.7 281.9 569.8 286.8 552.8L414.8 104.8C419.7 87.8 409.8 70.1 392.8 65.2zM457.4 201.3C444.9 213.8 444.9 234.1 457.4 246.6L530.8 320L457.4 393.4C444.9 405.9 444.9 426.2 457.4 438.7C469.9 451.2 490.2 451.2 502.7 438.7L598.7 342.7C611.2 330.2 611.2 309.9 598.7 297.4L502.7 201.4C490.2 188.9 469.9 188.9 457.4 201.4zM182.7 201.3C170.2 188.8 149.9 188.8 137.4 201.3L41.4 297.3C28.9 309.8 28.9 330.1 41.4 342.6L137.4 438.6C149.9 451.1 170.2 451.1 182.7 438.6C195.2 426.1 195.2 405.8 182.7 393.3L109.3 320L182.6 246.6C195.1 234.1 195.1 213.8 182.6 201.3z"/></svg>
            <h3>EcoLogits API</h3>
        </div>
        <div class="card-content">
            <p>An <b>API service</b> enabling integrations of our impact assessment methodology into your applications.</p>
            <div class="code-snippet-container">
                <div class="code-snippet">coming soon</div>
            </div>
        </div>
    </div>
</div>


## Contributors

People who contribute significantly to the project.

<div class="contributors-grid">
  <div class="contributor-card">
    <img src="https://avatars.githubusercontent.com/u/35747570" alt="Samuel Rincé">
    <div class="contributor-info">
      <span class="contributor-name">Samuel Rincé</span>
      <span class="contributor-role">AI Engineer</span>
    </div>
  </div>
  <div class="contributor-card">
    <img src="https://raw.githubusercontent.com/genai-impact/website/refs/heads/main/assets/images/people/claire_saignol.jpg" alt="Claire Saignol">
    <div class="contributor-info">
      <span class="contributor-name">Claire Saignol</span>
      <span class="contributor-role">Sustainability Manager</span>
    </div>
  </div>
  <div class="contributor-card">
    <img src="https://avatars.githubusercontent.com/u/45042779" alt="Adrien Banse">
    <div class="contributor-info">
      <span class="contributor-name">Adrien Banse</span>
      <span class="contributor-role">PhD Student</span>
    </div>
  </div>
  <div class="contributor-card">
    <img src="https://avatars.githubusercontent.com/u/12235628" alt="Valentin Defour">
    <div class="contributor-info">
      <span class="contributor-name">Valentin Defour</span>
      <span class="contributor-role">Data Scientist</span>
    </div>
  </div>
  <div class="contributor-card">
    <img src="https://avatars.githubusercontent.com/u/46927767" alt="Vincent Duarte">
    <div class="contributor-info">
      <span class="contributor-name">Vincent Duarte</span>
      <span class="contributor-role">Software Engineer</span>
    </div>
  </div>
</div>


## Sponsors

Organizations who make this project possible.

<div class="grid cards" markdown>
  <div class="row">
    <a href="https://resilio-solutions.com/" target="_blank">
      <img src="assets/sponsors/resilio.png" width="200">
    </a>
  </div>
  <div class="row">
    <a href="https://www.terra-cognita.ai/" target="_blank">
      <img src="assets/sponsors/terra_cognita.png" width="200">
    </a>
  </div>
  <div class="row">
    <a href="https://sopht.com/" target="_blank">
      <img src="assets/sponsors/sopht.png" width="200">
    </a>
  </div>
  <div class="row">
    <a href="https://www.avanade.com/" target="_blank">
      <img src="assets/sponsors/avanade.png" width="200">
    </a>
  </div>
  <div class="row">
    <a href="https://www.theodo.com/" target="_blank">
      <img src="assets/sponsors/theodo.png" width="200">
    </a>
  </div>
  <div class="row">
    <a href="https://www.culture.gouv.fr/fr" target="_blank">
      <img src="assets/sponsors/ministere_culture.png" width="200">
    </a>
  </div>
</div>

[//]: # (<div style="text-align: center;" markdown>)
[//]: # (  [Become a sponsor :octicons-heart-fill-24:{ .heart }]&#40;https://tally.so/r/wvLePd&#41;{ .md-button })
[//]: # (</div>)


## Acknowledgements

EcoLogits is part of the [CodeCarbon :octicons-link-external-16:](https://codecarbon.io/) non-profit. Together aim to build open and robust tools to assess and reduce the environmental footprint of AI.

We extend our gratitude to [Data For Good :octicons-link-external-16:](https://dataforgood.fr/) and [Boavizta :octicons-link-external-16:](https://boavizta.org/en) for supporting the development of this project. Their contributions of tools, best practices, and expertise in environmental impact assessment have been invaluable.
